workflow.WorkflowException

|  | ## Cheshire3 Object Model: Class WorkflowException

Module workflow :: Class WorkflowException

## Class WorkflowException
source code

Object Tree:

    exceptions.Exception --+
                           |
        c3errors.C3Exception --+
                               |
                              WorkflowException

Instance Methods

Inherited from `c3errors.C3Exception`: `__init__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Class Variables

Inherited from `c3errors.C3Exception`: `text`